<?php

namespace Litecms\GiftCard\Providers;

use Illuminate\Support\ServiceProvider;

class GiftCardServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'gift_card');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'gift_card');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('litecms.gift_card', function ($app) {
            return $this->app->make('Litecms\GiftCard\GiftCard');
        });

                // Bind GiftCard to repository
        $this->app->bind(
            'Litecms\GiftCard\Interfaces\GiftCardRepositoryInterface',
            \Litecms\GiftCard\Repositories\Eloquent\GiftCardRepository::class
        );

        $this->app->register(\Litecms\GiftCard\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Litecms\GiftCard\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litecms.gift_card'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litecms/gift_card.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/gift_card')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/gift_card')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
